@@ -70,11 +70,11 @@ Puppet::Type.type(:glance_image).provide(
 
     begin
       attrs = self.class.request('image', 'create', opts)
-      properties = self.class.parsestring(attrs[:properties]) rescue nil
+      properties = self.class.parse_python_dict(attrs[:properties])
       @property_hash = {
         :ensure           => :present,
         :name             => attrs[:name],
-        :is_public        => attrs[:visibility].downcase.chomp == 'public'? true : false,
+        :is_public        => attrs[:visibility].downcase.chomp == 'public'? :true : :false,
         :container_format => attrs[:container_format],
         :id               => attrs[:id],
         :disk_format      => attrs[:disk_format],
@@ -100,12 +100,12 @@ Puppet::Type.type(:glance_image).provide(
     @property_hash.clear
   end
 
-  mk_resource_methods
-
   def is_public
-    bool_to_sym(@property_hash[:is_public])
+    @property_hash[:is_public]
   end
 
+  mk_resource_methods
+
   [
     :is_public,
     :disk_format,
@@ -130,11 +130,11 @@ Puppet::Type.type(:glance_image).provide(
     list = request('image', 'list', '--long')
     list.collect do |image|
       attrs = request('image', 'show', image[:id])
-      properties = parsestring(attrs[:properties]) rescue nil
+      properties = parse_python_dict(attrs[:properties])
       new(
         :ensure           => :present,
         :name             => attrs[:name],
-        :is_public        => attrs[:visibility].downcase.chomp == 'public'? true : false,
+        :is_public        => attrs[:visibility].downcase.chomp == 'public'? :true : :false,
         :container_format => attrs[:container_format],
         :id               => attrs[:id],
         :disk_format      => attrs[:disk_format],
@@ -183,9 +183,6 @@ Puppet::Type.type(:glance_image).provide(
   private
 
   def self.exclude_readonly_props(props)
-    if props == nil
-      return nil
-    end
     hidden = [
       'os_hash_algo',
       'os_hash_value',
@@ -199,9 +196,6 @@ Puppet::Type.type(:glance_image).provide(
   end
 
   def self.exclude_owner_specified_props(props)
-    if props == nil
-      return nil
-    end
     rv = props.select { |k, v| not k.start_with?('owner_specified.') }
     return rv
   end
@@ -213,24 +207,6 @@ Puppet::Type.type(:glance_image).provide(
     }.compact
   end
 
-  def self.string2hash(input)
-    return Hash[input.scan(/(\S+)='([^']*)'/)]
-  end
-
-  def self.pythondict2hash(input)
-    return JSON.parse(input.gsub(/'/, '"').gsub(/False/,'false').gsub(/True/,'true'))
-  end
-
-  def self.parsestring(input)
-    if input[0] == '{'
-      # 4.0.0+ output, python dict
-      return self.pythondict2hash(input)
-    else
-      # Pre-4.0.0 output, key=value
-      return self.string2hash(input)
-    end
-  end
-
   def fetch(uri_str, proxy_host = nil, proxy_port = nil, limit = 10)
     raise RuntimeError, 'Too many HTTP redirections' if limit == 0
 
