@@ -41,26 +41,25 @@ Puppet::Type.newtype(:glance_image) do
   newproperty(:is_public) do
     desc "Whether the image is public or not. Default true"
     newvalues(/(y|Y)es/, /(n|N)o/, /(t|T)rue/, /(f|F)alse/, true, false)
-    defaultto(true)
-    munge do |v|
-      if v =~ /^(y|Y)es$/
+    defaultto(:true)
+    munge do |value|
+      case value.to_s.downcase
+      when 'true', 'yes'
         :true
-      elsif v =~ /^(n|N)o$/
-        :false
       else
-        v.to_s.downcase.to_sym
+        :false
       end
     end
   end
 
   newproperty(:container_format) do
     desc "The format of the container"
-    newvalues(:ami, :ari, :aki, :bare, :ovf)
+    newvalues(:ami, :ari, :aki, :bare, :ovf, :ova, :docker, :compressed)
   end
 
   newproperty(:disk_format) do
     desc "The format of the disk"
-    newvalues(:ami, :ari, :aki, :vhd, :vmdk, :raw, :qcow2, :vdi, :iso, :ploop)
+    newvalues(:ami, :ari, :aki, :vhd, :vhdx, :vmdk, :raw, :qcow2, :vdi, :iso, :ploop)
   end
 
   newparam(:source) do
@@ -94,21 +93,11 @@ Puppet::Type.newtype(:glance_image) do
   newproperty(:properties) do
     desc "The set of image properties"
 
-    munge do |value|
-      return value if value.is_a? Hash
-
-      Hash[value.scan(/([^,=]+)=([^,]*)/)]
-    end
-
     validate do |value|
       if value.is_a?(Hash)
         return true
-      elsif value.is_a?(String)
-        value.split(',').each do |property|
-          raise ArgumentError, "Key/value pairs should be separated by an =" unless property.include?('=')
-        end
       else
-        raise ArgumentError, "Invalid properties #{value}. Requires a String or a Hash, not a #{value.class}"
+        raise ArgumentError, "Invalid properties #{value}. Requires a Hash, not a #{value.class}"
       end
     end
   end
