@@ -41,7 +41,6 @@ describe 'glance::api' do
       :image_location_quota           => '<SERVICE DEFAULT>',
       :image_size_cap                 => '<SERVICE DEFAULT>',
       :user_storage_quota             => '<SERVICE DEFAULT>',
-      :disk_formats                   => '<SERVICE DEFAULT>',
       :paste_deploy_flavor            => 'keystone',
       :paste_deploy_config_file       => '<SERVICE DEFAULT>',
       :task_time_to_live              => '<SERVICE DEFAULT>',
@@ -215,6 +214,7 @@ describe 'glance::api' do
         it 'is_expected.to have no formats set' do
           is_expected.to contain_glance_api_config('image_format/container_formats').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_glance_api_config('image_format/require_image_format_match').with_value('<SERVICE DEFAULT>')
         end
 
         it 'passes purge to resource' do
@@ -247,16 +247,6 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_value('something') }
     end
 
-    describe 'with flavor overridden by the deprecated pipeline parameter' do
-      let :params do
-        {
-          :pipeline => 'something',
-        }
-      end
-
-      it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_value('something') }
-    end
-
     context 'when running glance-api in wsgi' do
       let :params do
         {
@@ -282,24 +272,6 @@ describe 'glance::api' do
       end
     end
 
-    context 'when service_name is not valid' do
-      let :params do
-        {
-          :service_name => 'foobar'
-        }
-      end
-
-      let :pre_condition do
-        "include apache
-         class { 'glance': }
-         class { 'glance::api::authtoken':
-           password => 'foo',
-         }"
-      end
-
-      it_raises 'a Puppet::Error', /Invalid service_name/
-    end
-
     describe 'with platform default oslo concurrency lock_path' do
       it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
         :lock_path => platform_params[:lock_path]
@@ -370,6 +342,18 @@ describe 'glance::api' do
       end
     end
 
+    describe 'with require_image_format_match' do
+      let :params do
+        {
+          :require_image_format_match => true,
+        }
+      end
+
+      context 'with require_image_format_match option' do
+        it { is_expected.to contain_glance_api_config('image_format/require_image_format_match').with_value(true) }
+      end
+    end
+
     describe 'with enabled_backends and stores by default' do
       it { is_expected.to_not contain_glance_api_config('DEFAULT/enabled_backends').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
