@@ -16,8 +16,9 @@ describe 'glance' do
         let(:params) do
           { :package_ensure => package_ensure }
         end
-        it { is_expected.to contain_package('openstack-glance').with(
+        it { is_expected.to contain_package('glance').with(
           :ensure => package_ensure,
+          :name   => 'openstack-glance',
           :tag    => ['openstack', 'glance-package']
         )}
       end
@@ -33,8 +34,8 @@ describe 'glance' do
       end
 
       it_behaves_like 'glance'
-      if facts[:osfamily] == 'RedHat'
-        it_configures "glance on #{facts[:osfamily]}"
+      if facts[:os]['family'] == 'RedHat'
+        it_configures "glance on #{facts[:os]['family']}"
       end
     end
   end
