@@ -7,7 +7,6 @@ describe 'glance::notify::rabbitmq' do
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
@@ -17,12 +16,16 @@ describe 'glance::notify::rabbitmq' do
         :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
         :kombu_failover_strategy         => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                => '<SERVICE DEFAULT>',
         :kombu_compression               => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :use_queue_manager               => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       ) }
 
@@ -51,13 +54,15 @@ describe 'glance::notify::rabbitmq' do
           :rabbit_ha_queues                   => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
           :rabbit_use_ssl                     => true,
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
@@ -67,6 +72,7 @@ describe 'glance::notify::rabbitmq' do
           :kombu_reconnect_delay              => '5.0',
           :kombu_failover_strategy            => 'shuffle',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => false,
           :kombu_compression                  => 'gzip',
           :notification_transport_url         => 'rabbit://user:pass@alt_host:1234/virt',
           :notification_topics                => 'notification',
@@ -79,7 +85,6 @@ describe 'glance::notify::rabbitmq' do
         :rabbit_ha_queues                => true,
         :heartbeat_timeout_threshold     => '60',
         :heartbeat_rate                  => '10',
-        :heartbeat_in_pthread            => true,
         :rabbit_qos_prefetch_count       => 0,
         :rabbit_use_ssl                  => true,
         :kombu_ssl_ca_certs              => '/etc/ca.cert',
@@ -89,12 +94,16 @@ describe 'glance::notify::rabbitmq' do
         :kombu_reconnect_delay           => '5.0',
         :kombu_failover_strategy         => 'shuffle',
         :amqp_durable_queues             => true,
+        :amqp_auto_delete                => false,
         :kombu_compression               => 'gzip',
         :rabbit_quorum_queue             => true,
         :rabbit_transient_quorum_queue   => true,
+        :rabbit_transient_queues_ttl     => 60,
         :rabbit_quorum_delivery_limit    => 3,
         :rabbit_quorum_max_memory_length => 5,
         :rabbit_quorum_max_memory_bytes  => 1073741824,
+        :use_queue_manager               => true,
+        :rabbit_stream_fanout            => true,
         :enable_cancel_on_failover       => false,
       ) }
 
